function [newCenter, radius] =centerSearch(Image, guessCenter, guessRadius)

%determines how long a region of the profile is examined
profileExaminationWidth=3;

%global constansts set in auto3d_track
global checkLocations;
global checkLength;
global maxSearchDisplacement;

%converts an image to double values
Image=im2double(Image);

%creates arrays to hold values found in loop below
peakSharpness=zeros(checkLength,1);
meanVals=zeros(checkLength,1);
radii=zeros(checkLength,1);

%run this loop through all the positions in the LUT created in auto3d_track
for p=1:checkLength

    %set the two index variables into the image based upin the LUT
    i=checkLocations(1,p);
    j=checkLocations(2,p);

    %get profile using createProfile_advanced function and a guessed center
    profile=createProfile_advanced(Image,guessCenter+[j,i],guessRadius-profileExaminationWidth-3,...
        guessRadius+profileExaminationWidth+3);

    %create subprofile array so only relevent portion of profile is observed
    tempProfile=zeros(length(profile),1);

    %make sure there is no error from the tempProfile going below 1 in the
    %index (will cause an error)
    if(guessRadius-profileExaminationWidth<1)
        guessRadius=profileExaminationWidth+1;
    end


    %set the temp profile to the region of the profile within
    %profileExaminationWidth of the guessed radius
    tempProfile(guessRadius-profileExaminationWidth:...
        guessRadius+profileExaminationWidth)=profile(guessRadius...
        -profileExaminationWidth:guessRadius+profileExaminationWidth);

    %plot so that profile is visible
%     figure
%     plot(profile(2:length(profile)),'.')
%     hold on

    %find the maximum point of the tempProfile (choose the first if there are
    %several)
    maxLoc=find(tempProfile==max(tempProfile));
    maxLoc=maxLoc(1);

    %hard edges of search region (used for fitting.  Don't want to go too
    %far and screw up the fit.  These values tend to work well, but may be
    %changed.  It depends upon the smoothness of the profile)
    ledge=maxLoc-3;
    redge=maxLoc+3;

    %next two if statements used to ensure that the edges don't force you 
    %off the profile, causing an error (less than 1 or too long)
    if(ledge<=0)
        ledge=1;
    end
    
    if(redge>length(profile))
        redge=length(profile);
    end

    %look only at the further reduced region around the found max
    x=[ledge:redge];

    %use only that profile between edges, and have it start at zero
    tempProfile=profile(x);

    %fit the profile and use this new value
    P=polyfit(x,tempProfile,2);
    radius=-P(2)/(2*P(1))-1;
    radii(p)=radius;

    %store the "sharpness" of this peak.  The sharpest peak will be chosen
    %as the real one, as it means there is the least smoothing out of the 
    %ring caused by being in the wrong place 
    x=[ledge:.1:redge];
    peakSharpness(p)=P(1);
end

%find the most negative peak (the sharpest) if several are found choose the
%first.  This will be used to find the appropriate radius and final center
location=find(peakSharpness==min(peakSharpness));
location=location(1);

%get the radius in the radii array where the sharpest peak occured
radius=radii(location);

%grab the i and j offsets that were used to find the sharpest peak
i=checkLocations(1,location);
j=checkLocations(2,location);

%set the new center to the guessed center plus the relevant i and j
newCenter=guessCenter+[j i];