% close all;

% get number of frames;
Nt=length(rlt);

global p_scale;
global r_scale;

%New Camera
% p_scale=.8;
% r_scale=3.2402;

%Old Camera, define pixel scale and radius scale
p_scale=12.9/20;
r_scale=2.1862;

min_l=6;    %minimum length of a track to be observed
dmax=8;     %Maximal allowable displacement;

%set up points for first two frames
x1=rlt(1).x;  y1=rlt(1).y;  r1=rlt(1).r;
x2=rlt(2).x;  y2=rlt(2).y;  r2=rlt(2).r;

%use match_pair to connect them
[IA1, IA2, dxA, dyA]=match_pair(x1,y1,x2,y2,r1,r2,dmax);

%set n_track to the number of tracks found so far
n_track=length(IA1);

%run through all these found pairs creating tracks, and scaling them
for i=1:n_track
    
    %create a new track in structure tk for each trajectory found
    tk(i)=struct('x',zeros(1,Nt-1),'y',zeros(1,Nt-1),'z',zeros(1,Nt-1),...
        'dx',zeros(1,Nt-1), 'dy',zeros(1,Nt-1),'t',zeros(1,Nt-1),'np',...
        1,'curr',IA2(i) );           
  
    %set the values of this entry in the structure, and average the results
    %to smooth out the results
    tk(i).x(1)=p_scale*0.5*(x1(IA1(i))+x2(IA2(i)));
    tk(i).y(1)=p_scale*0.5*(y1(IA1(i))+y2(IA2(i)));
    tk(i).z(1)=r_scale*0.5*(r1(IA1(i))+r2(IA2(i)));
    tk(i).dx(1)=dxA(i);
    tk(i).dy(1)=dyA(i);
    tk(i).t(1)=1;
end


%loop through all remaining frames
for i=3:Nt
     
    
    %load new frames points
    x3=rlt(i).x;  y3=rlt(i).y;  r3=rlt(i).r;
    
    %match these new points to the last frame
    [IB1, IB2, dxB, dyB]=match_pair(x2,y2,x3,y3,r2,r3,dmax);    
    
    %create an array to hold flags for when a point has not been added to a
    %track
    flag=ones( 1,length(IB1) );
    
    % Look through particle tracks, find out if they have matches with a point 
    % in the next time step. If yes, append the track with new location 
    % and displacement; if not, terminate this track
    for j=1:n_track
        
        %if this track last occured too long ago, do not try to append
        if(tk(j).t( tk(j).np ) < i-2)
            continue;
        end
        
        %find the point that matches this track (if any do)
        I=find(tk(j).curr == IB1);
        
        %if nothing matches with this track, settle the track (choose those
        %values for points it already has)
        if(isempty(I))
            tk(j).x = tk(j).x(1: tk(j).np);
            tk(j).y = tk(j).y(1: tk(j).np);
            tk(j).z = tk(j).z(1: tk(j).np);
            tk(j).dx = tk(j).dx(1: tk(j).np);
            tk(j).dy = tk(j).dy(1: tk(j).np);
            tk(j).t = tk(j).t(1: tk(j).np);
        else
            
            %if something matches to this track add another point to it
            tk(j).np = tk(j).np + 1;
            tk(j).curr = IB2(I);
            np=tk(j).np;
            
            %set the new point on this trajectory to the average of the two
            %values to smooth it out
            tk(j).x(np) = p_scale*0.5*( x2(IB1(I)) +x3(IB2(I)) );
            tk(j).y(np) = p_scale*0.5*( y2(IB1(I)) +y3(IB2(I)) );
            tk(j).z(np) = r_scale*0.5*( r2(IB1(I)) +r3(IB2(I)) );
            tk(j).dx(np) = dxB(I);
            tk(j).dy(np) = dyB(I);
            tk(j).t(np) =  i-1;
            
            %set this points flag to 0 as it has been added to a track
            flag(I)=0;
        end        
    end
    
    % For those new particle pairs that do not have match with previous
    % tracks, start a new track
    J=find(flag==1);
    n_newtrack=length(J);   % No of new tracks
    
    %create new tracks for all those matched points that can't be appended
    %to an old track
    for j=1:n_newtrack
        jj=J(j);
        n_track=n_track+1;
        % Create a new track
        tk(n_track)= struct('x',zeros(1,Nt-1),'y',zeros(1,Nt-1),'z',zeros(1,Nt-1),...
            'dx',zeros(1,Nt-1), 'dy',zeros(1,Nt-1),'t',zeros(1,Nt-1),...
            'np',1,'curr',IB2(jj) ); 
             
        tk(n_track).x(1)= p_scale*0.5*( x2(IB1(jj)) + x3(IB2(jj)) );
        tk(n_track).y(1)= p_scale*0.5*( y2(IB1(jj)) + y3(IB2(jj)) );
        tk(n_track).z(1)= r_scale*0.5*( r2(IB1(jj)) + r3(IB2(jj)) );
        tk(n_track).dx(1)= dxB(jj) ;
        tk(n_track).dy(1)= dyB(jj) ;   
        tk(n_track).t(1)= i-1;
    end
    
    IA1=IB1;    IA2=IB2;    dxA=dxB;    dyA=dyB;
    x1=x2;  y1=y2;  r1=r2;
    x2=x3;  y2=y3;  r2=r3;
end


n_track

%prepare figure
figure;
hold on
axis equal
%axis([0 230 0 415 0 120])

%set variable for counting skiped tracks and setting the
%minimum length of a track to be shown
counter_skip=0;

cindex=0;
cols(1).c='b';
cols(2).c='r';
cols(3).c='g';
cols(4).c='k';
cols(5).c='c';
cols(6).c='m';

for i=1:n_track
    tk(i).x = tk(i).x(1: tk(i).np);
    tk(i).y = tk(i).y(1: tk(i).np);
    tk(i).z = tk(i).z(1: tk(i).np);
    tk(i).dx = tk(i).dx(1: tk(i).np);
    tk(i).dy = tk(i).dy(1: tk(i).np);
    tk(i).t = tk(i).t(1: tk(i).np);
    %continue
    if(tk(i).np<min_l)
        counter_skip=counter_skip+1;
        continue;
    end
    cindex=cindex+1;
    if cindex>6
        cindex=1;
    end
    plot3( tk(i).x, tk(i).y, tk(i).z,cols(cindex).c);
end

save tracks tk;
axis equal
hold off
display(sprintf('%d tracks were skipped because they were shorter than %d points in length.',counter_skip,min_l))
