function [xi,yi,ri]=remove_circle(xc,yc,r)

%determine number of particles, and turn vectors into columns
nc=length(xc);
xc=reshape(xc,nc,1);
yc=reshape(yc,nc,1);
r=reshape(r,nc,1);

%limit as to how close to the guessed error radius
%something must be to be considered an error
r_kill_limit=5;

%create a matrix of center position distances
dx=xc*ones(1,nc)-ones(nc,1)*xc';
dy=yc*ones(1,nc)-ones(nc,1)*yc';
dcen=sqrt(dx.^2+dy.^2);

%create a matrix of the means of x and y locations
xm=(xc*ones(1,nc)+ones(nc,1)*xc')/2;
ym=(yc*ones(1,nc)+ones(nc,1)*yc')/2;

%create a matrix of the sums of radii
rab=r*ones(1,nc)+ones(nc,1)*r';

%index increasing by row matrix
HI=[1:nc]'*ones(1,nc);

%index increasing by column matrix
HJ=ones(nc,1)*[1:nc];

%vector holding indicies of circles to be maintained
J=[];

%loop through all located particles
for i=1:nc
    %set radius for an "inner ring" error
    r_inner=(rab-dcen)/2;
    
    %set radius for an "outer ring" error
    r_outer=(rab+dcen)/2;
    
    %find range of the center of this circle to the mean centers
    %where possible error circles could exist
    cen_range=sqrt((xc(i)-xm).^2+(yc(i)-ym).^2);
    
    %set first flag to true if the distance between the centers is less than
    %the sum of the radii (required) and if the radius is within the kill
    %limit of either the outer or the inner error radius guess
    flag=((abs(r(i)-r_inner)<r_kill_limit)+(abs(r(i)-r_outer)<r_kill_limit)).*(dcen<rab);
    
    %modify flag such that the center range from this circle to others is
    %less than half the distance between two given circles, as it must be at
    %least this close to one of the centers of the real rings that produced
    %the false circle, and because the true circles will be the distance
    %divided by two away from the mean of the two circl'es centers
    flag=flag.*(cen_range<dcen/2);
    
    %only include those in which the current index
    %applies to neither the column nor the row
    flag2=(HI~=i).*(HJ~=i);
    
    %combine flags to generate final flag matrix
    %the eye is to ignore the diagional (particles
    %compared against themselves)
    flag=flag.*flag2.*(1-eye(nc,nc));
    
    %make I a list of positive flags
    I=find(flag>0);
    
    %if no flags were produced, include this "find" in the list
    %of desired particles to be maintained
    if(isempty(I));
        J=[J i];
    end
end

%select those that are desired to be included, and store for ouput
xi=xc(J);
yi=yc(J);
ri=r(J);

